#ifndef NT2_INCLUDE_FUNCTIONS_RROL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_RROL_HPP_INCLUDED

#include <nt2/bitwise/include/functions/rrol.hpp>

#endif
